Skip to contents

This is an internal function that runs if a user does not provide a contrasts table to run_delta_EAF_contrasts(). It will produce an all-by-all table and run through validate_delta_EAF_contrasts() to modify the class.

Usage

make_delta_EAF_contrasts(q)

Arguments

q

a qSIP2 list object

Value

a dataframe