Skip to contents

Plot the source WADs by isotope

Usage

plot_source_wads(qsip_data, group = NULL, title = NULL)

Arguments

qsip_data

(qsip_data) qSIP object

group

(character) An optional grouping parameter to facet the y or x,y axes. Can be a single column name or vector of column names from source metadata. Multiple columns are combined with "_" separator (e.g., group = c("Moisture", "isotopolog") creates "Drought_glucose", "Normal_glucose").

title

(character) An optional title for the plot

Value

A ggplot object