Calculate NA probabilities for resampling scenarios
Source:R/calculate.R
calculate_na_probabilities.RdCalculates the probability of successful mean calculation and the probability of all values being NA for different counts of non-NA values in a sample of size n. Useful for understanding the impact of missing data on resampling.