Plot qSIP sample data density curves
Usage
plot_sample_curves(
qsip_data_object,
title = NULL,
facet_by = "source",
show_wad = FALSE,
colors = lifecycle::deprecated()
)Arguments
- qsip_data_object
(qsip_data) qSIP object
- title
(character) An optional title for the plot
- facet_by
(character) Facet the plots by "source" (one panel per source_mat_id), "isotope" (one panel per isotope), or by any column name(s) from the source metadata. For a single column or vector of columns, creates a facet_grid with isotope as rows and the specified column(s) as columns. Multiple columns are combined with "_" separator (e.g.,
facet_by = c("Moisture", "Isotopolog")creates "Drought_glucose", "Normal_glucose"). For custom faceting, replicates within each isotope × facet group are assigned numbers and colored accordingly.- show_wad
(logical) A logical value indicating whether to show WAD lines
- colors
deprecated
See also
Other "visualizations":
plot_density_outliers(),
plot_feature_curves(),
plot_filter_results(),
plot_source_wads()